@@ -390,6 +390,15 @@ sub hash_fetch {
     return $self->_hash_fetch( $name, $key );
 } #hash_fetch
 
+
+sub hash_has_key {
+    my( $self, $args, $account ) = @_;
+    die "Access Error" unless $self->_check_access( $account, 0, $args->{ name } );
+    my( $name, $key ) = @$args{'name','key'};
+
+    return $self->_hash_has_key( $name, $key );
+} #hash_has_key
+
 sub insert_at {
     my( $self, $args, $account ) = @_;
     die "Access Error" unless $self->_check_access( $account, 1, $args->{ name } );
@@ -693,7 +702,7 @@ This method is called each time an object is loaded from the data store.
 
 =over 4
 
-=item add_to( { name => '', items => [] } )
+=item add_to( { name => container_name, items => [] } )
 
 Adds the items to the list attached to this object specified by name.
 
@@ -705,27 +714,29 @@ returns the class name of the given container from this host object.
 
 Returns the number of items for the field of this object provided it is an array or hash.
 
-=item delete_key( { name => '', key => '' } )
+=item delete_key( { name => container_name, key => '' } )
 
 Removes the key from the hash attached to this object specified by name.
 
-=item hash( { name => '', key => '', value => item } )
+=item hash( { name => container_name, key => '', value => item } )
 
 Hashes the item to the key to the hash attached to this object specified by name.
 
-=item hash_fetch( { name => '', key => '' } )
+=item hash_fetch( { name => container_name, key => '' } )
 
 Returns the item from the named hash by key.
 
-=item insert_at( { name => '', index => '', item => item } )
+=item hash_has_key( { name => container_name, key => keytotest } );
+
+=item insert_at( { name => container_name, index => '', item => item } )
 
 Insert the item at the index to the list attached to this object specified by name.
 
-=item list_delete( { name => '', index => '' } )
+=item list_delete( { name => container_name, index => '' } )
 
 Removes the item at the index postion from the list attached to this object specified by name.
 
-=item list_fetch( { name => '', index => '' } )
+=item list_fetch( { name => container_name, index => '' } )
 
 Returns item at the index postion from the list attached to this object specified by name.
 
@@ -752,7 +763,7 @@ Returns a paginated list or hash. Arguments are
 
 =back
 
-=item remove_from( { name => '', items => [] } )
+=item remove_from( { name => container_name, items => [] } )
 
 Removes the items ( by value ) from the list attached to this object specified by name.
 
